# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from __future__ import absolute_import, division, print_function

from stripe.api_resources.abstract import ListableAPIResource


class CreditNoteLineItem(ListableAPIResource):
    """
    The credit note line item object
    """

    OBJECT_NAME = "credit_note_line_item"
